@@ -1,5 +1,8 @@
 package Git::Database;
-$Git::Database::VERSION = '0.005';
+$Git::Database::VERSION = '0.006';
+use strict;
+use warnings;
+
 use Module::Runtime qw( use_module );
 
 use Moo::Object ();
@@ -36,7 +39,7 @@ Git::Database - Provide access to the Git object database
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
